<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AssemblyGui::TaskAssemblyConstraints</name>
    <message>
        <location filename="../../TaskAssemblyConstraints.cpp" line="52"/>
        <source>Constraints</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AssemblyGui::Workbench</name>
    <message>
        <location filename="../../Workbench.cpp" line="94"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyAddExistingComponent</name>
    <message>
        <location filename="../../Command.cpp" line="154"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="155"/>
        <source>Add existing Component...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="156"/>
        <source>Add a existing Component into the active Assembly, STEP, IGES or BREP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyAddNewComponent</name>
    <message>
        <location filename="../../Command.cpp" line="108"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="109"/>
        <source>Add new Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="110"/>
        <source>Add a new Subassembly into the active Assembly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyAddNewPart</name>
    <message>
        <location filename="../../Command.cpp" line="52"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="53"/>
        <source>Add new Part</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="54"/>
        <source>Add a new Part into the active Assembly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyConstraint</name>
    <message>
        <location filename="../../CommandConstraints.cpp" line="118"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="119"/>
        <source>Constraint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="120"/>
        <source>Add arbitrary constraints to the assembly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyConstraintAlignment</name>
    <message>
        <location filename="../../CommandConstraints.cpp" line="539"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="540"/>
        <source>Constraint alignment...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="541"/>
        <source>Align the selected entities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyConstraintAngle</name>
    <message>
        <location filename="../../CommandConstraints.cpp" line="334"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="335"/>
        <source>Constraint Angle...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="336"/>
        <source>Set the angle between two selected entities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyConstraintCoincidence</name>
    <message>
        <location filename="../../CommandConstraints.cpp" line="471"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="472"/>
        <source>Constraint coincidence...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="473"/>
        <source>Make the selected entities coincident</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyConstraintDistance</name>
    <message>
        <location filename="../../CommandConstraints.cpp" line="202"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="203"/>
        <source>Constraint Distance...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="204"/>
        <source>Set the distance between two selected entities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyConstraintFix</name>
    <message>
        <location filename="../../CommandConstraints.cpp" line="269"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="270"/>
        <source>Constraint Fix...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="271"/>
        <source>Fix a part in it&apos;s rotation and translation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyConstraintOrientation</name>
    <message>
        <location filename="../../CommandConstraints.cpp" line="403"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="404"/>
        <source>Constraint Orientation...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="405"/>
        <source>Set the orientation of two selected entities in regard to each other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdAssemblyImport</name>
    <message>
        <location filename="../../Command.cpp" line="217"/>
        <source>Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="218"/>
        <source>Import assembly...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="219"/>
        <source>Import one or more files and create a assembly structure.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Command.cpp" line="73"/>
        <location filename="../../Command.cpp" line="129"/>
        <location filename="../../Command.cpp" line="175"/>
        <source>No active or selected assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="74"/>
        <source>You need a active or selected assembly to insert a part in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="130"/>
        <location filename="../../Command.cpp" line="176"/>
        <source>You need a active or selected assembly to insert a component in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="70"/>
        <source>No active Assembly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandConstraints.cpp" line="71"/>
        <source>You need a active (blue) Assembly to insert a Constraint. Please create a new one or make one active (double click).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TaskAssemblyConstraints</name>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="22"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;The first geometry to which the constraint relates. Note that first and second geometry can be swapt. If you want to clear it, use the button to the right. If it is empty, just select any geometry in the 3D view and it will be added here.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Clear the first geometry&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="38"/>
        <location filename="../../TaskAssemblyConstraints.ui" line="72"/>
        <location filename="../../TaskAssemblyConstraints.ui" line="439"/>
        <location filename="../../TaskAssemblyConstraints.ui" line="477"/>
        <location filename="../../TaskAssemblyConstraints.ui" line="512"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;The second geometry to which the constraint relates. Note that first and second geometry can be swapt. If you want to clear it, use the button to the right. If it is empty, just select any geometry in the 3D view and it will be added here.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="69"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Clear the second geometry&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="113"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Set the angle between the geometries normals&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="116"/>
        <source>Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Special constraint which is in general used to let the geometries be on each other. Therefore it&apos;s often the same as align, with the difference that it is also defined for points, as a point can lie on a plane. Note that this constraint has a special behaviour for cylinders. For example, a cylindrical surface can&apos;t be on a plane, only touch it. Therefore this is not valid. Furthermore point and line coincident with cylinders don&apos;t work on the cylinder surface, but on its center line. The reason for that it is, that this centerline would not be accessible with other constraints, but the surface coincident can be also achieved with the align constraint and value 0.  At last specialty the cylinder cylinder constraint shall be mentioned: It works also on the cylinder centerlines and therefore makes them concentric. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="157"/>
        <source>Coincident</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="195"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fixes the first geometry in its rotation and translation. Note that fix only works its the direct parent assembly. If you stack assemblies, the parent assembly will not be fixed inside the other ones.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="198"/>
        <source>Fix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="236"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Set the distance between first and second geometry. Note that in many cases the shortest distance is used (e.g. line - line)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="239"/>
        <source>Distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="277"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Allows to set the orientation of the geometries normals in relation to each other. Possible values are parallel (means equal or opposite normals), equal normals, opposite normals or perpendicular ones. Note that for cylinders the base circles normal is used.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="280"/>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="318"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Adds a orientation and a distance constraint. Therefore this constraint is only valid where both of the individual constraints are, e.g. you can&apos;t align a point and a plane as point-plane orientation is invalid. Furthermore it can happen that this constraint is only valid for a certain orientation, e.g. plane - line has only a defined distance, when the orientation is perpendicular. The reason behind this is, that a non-perpendicular line would always cut the plane and therefore the shortest distance would always be 0. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="321"/>
        <source>Align</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="413"/>
        <source>value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="436"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Use the full solution space. The nearest solution will be found.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="474"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Positive solution space. Reduces the valid solutions to the positive domain, e.g. point over the plane at specified distance, not under. Or point outside a cylinder at specified distance, not inside.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="509"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Negative solution space. Reduces the valid solutions to the negative domain, e.g. point under the plane at specified distance, not over. Or point inside a cylinder at specified distance, not outside.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="566"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Makes the geometries normals parallel, that means they can point in the same or opposite direction. Note that for cylinders the base circles normal is used.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="569"/>
        <source>Parallel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="604"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Makes the geometries normals point in the same direction. Note that for cylinders the base circles normal is used.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="607"/>
        <source>Equal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="645"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Makes the geometries normals point in the opposite direction. Note that for cylinders the base circles normal is used.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="648"/>
        <source>Opposite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="683"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Makes the geometries normals perpendicular. Note that for cylinders the base circles normal is used.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskAssemblyConstraints.ui" line="689"/>
        <source>Perpend.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
